@@ -5,7 +5,7 @@ from typing import List, Union
 from pathlib import Path
 
 
-__version__ = "2022.6.30.3"
+__version__ = "2022.7.20.1"
 log_format = logging.Formatter(
     "[%(asctime)s] %(filename)s/%(lineno)s/%(funcName)s/%(levelname)s: %(message)s"
 )
@@ -131,8 +131,14 @@ def configure_logger(
 
             # StreamHandler 类型的处理器只保留一个
             if type(handler) == logging.StreamHandler:
-                logger.debug(f"StreamHandler 类型处理器已经存在（控制台只保留一个），忽略：{handler}")
-                continue
+                if new_console_handler:
+                    logger.addHandler(handler)
+                    # 各Handler与Logger采用统一的level级别
+                    if unify_level:
+                        handler.setLevel(level)
+                else:
+                    logger.debug(f"StreamHandler 类型处理器已经存在（控制台只保留一个），忽略：{handler}")
+                    continue
 
             # FileHandler 类型处理器不重复，输出到同一目的地的只保留一个
             if isinstance(handler, logging.FileHandler):
@@ -146,7 +152,11 @@ def configure_logger(
                     logger.addHandler(handler)
                     log_file_list.append(str(handler.baseFilename))
             elif isinstance(handler, logging.Handler):
-                logger.warning(f"忽略日志Handler：{handler}")
+                # logger.warning(f"忽略日志Handler：{handler}")
+                # 各Handler与Logger采用统一的level级别
+                if unify_level:
+                    handler.setLevel(level)
+                logger.addHandler(handler)
             else:
                 raise TypeError(f"类型错误，预期为{logging.Handler}类型，实际为{type(handler)}类型")
 
