@@ -199,8 +199,17 @@ class MyCache(object):
         self._dict[name] = value
         self.save_cache()
 
-    def hmset(self, key: str, value):
-        self.set(key, value)
+    def hset(self, name, key=None, value=None, mapping=None):
+        if (key and mapping) or (not key and not mapping):
+            raise ValueError("参数key与mapping必须二选一")
+
+        if key:
+            self._dict[name][key] = value
+        else:
+            self.set(name, mapping)
+
+    def hmset(self, name, mapping):
+        self.set(name, mapping)
 
     def hgetall(self, key: str):
         return self.get(key)
